package com.chelvc.cloud.admin.controller;

import java.util.List;
import javax.validation.Valid;
import javax.validation.constraints.Min;
import javax.validation.constraints.NotEmpty;

import com.chelvc.cloud.vehicle.client.FeedbackClient;
import com.chelvc.cloud.vehicle.client.dto.FeedBackDTO;
import com.chelvc.cloud.vehicle.client.param.FeedBackPagingParam;
import com.chelvc.framework.base.annotation.ResponseWrapping;
import com.chelvc.framework.common.model.Pagination;
import lombok.RequiredArgsConstructor;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RestController;

/**
 * 意见反馈接口
 *
 * @author liude
 * @date 2023/1/16
 */
@Validated
@RestController
@ResponseWrapping
@RequiredArgsConstructor(onConstructor = @__(@Autowired))
public class FeedbackController {
    private final FeedbackClient feedbackClient;

    /**
     * 查询意见反馈
     */
    @GetMapping("/feedback/query")
    public List<FeedBackDTO> queryById(@Valid @NotEmpty String channel) {
        return this.feedbackClient.getFeedback(channel);
    }

    /**
     * 查询意见反馈分页
     *
     * @param param 查询参数
     * @return 查询意见反馈分页信息
     */
    @GetMapping("/feedback/paging")
    public Pagination<FeedBackDTO> getFeedbackPaging(@Valid FeedBackPagingParam param) {
        return this.feedbackClient.getFeedbackPaging(param);
    }


    /**
     * 更新意见反馈状态
     */
    @GetMapping("/feedback/{id}")
    public void updateStatus(@PathVariable("id") @Min(value = 1, message = "商家主键不能小于1") Long id,
                             String state) {
        this.feedbackClient.updateStatus(id, state);
    }


}
