package com.chelvc.cloud.admin.controller;

import javax.validation.Valid;

import com.chelvc.cloud.user.client.LoginClient;
import com.chelvc.cloud.user.client.dto.LoginDTO;
import com.chelvc.cloud.user.client.param.LoginPagingParam;
import com.chelvc.framework.base.annotation.ResponseWrapping;
import com.chelvc.framework.common.model.Pagination;
import lombok.RequiredArgsConstructor;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RestController;

/**
 * 用户登陆记录接口
 *
 * @author liude
 * @date 2024/4/30
 */
@Validated
@RestController
@ResponseWrapping
@RequiredArgsConstructor(onConstructor = @__(@Autowired))
public class LoginController {
    private final LoginClient loginClient;

    /**
     * 查询用户分页
     *
     * @param param 查询参数
     * @return 用户分页信息
     */
    @GetMapping("/login/paging")
    public Pagination<LoginDTO> getLoginPaging(@Valid LoginPagingParam param) {
        return this.loginClient.getLoginPaging(param);
    }
}
